<?php
/**
 * Plugin Name: 智能图片alt优化版
 * Description: 精准识别图片特征生成唯一alt，支持自动排除无效命名
 * Version: 1.2
 * Author: Your Name
 */

if (!defined('ABSPATH')) exit;

add_filter('the_content', 'enhanced_alt_generator');

function enhanced_alt_generator($content) {
    static $counter = 1; // 静态计数器保持文章内连续
    $post_title = get_the_title();

    $content = preg_replace_callback('/<img[^>]+>/i', function ($matches) use ($post_title, &$counter) {
        $img_tag = $matches[0];
        
        // 跳过已有非空alt
        if (preg_match('/\salt=(["\'])(?<alt>.*?)\1/i', $img_tag, $alt_match) && !empty(trim($alt_match['alt']))) {
            return $img_tag;
        }

        $alt_text = '';
        $attachment_id = 0;

        // 精准获取附件ID（新增URL解码处理）
        if (preg_match('/wp-image-([0-9]+)/i', $img_tag, $id_match)) {
            $attachment_id = $id_match[1];
        } else if (preg_match('/src=(["\'])(?<src>.*?)\1/i', $img_tag, $src_match)) {
            $decoded_src = urldecode($src_match['src']); // 处理URL编码
            $attachment_id = attachment_url_to_postid($decoded_src);
        }

        // 特征提取流程
        if ($attachment_id) {
            // 1. 媒体库alt优先
            $alt_text = get_post_meta($attachment_id, '_wp_attachment_image_alt', true);

            // 2. 智能文件名分析（新增语义检测）
            if (empty($alt_text)) {
                $file_name = basename(get_attached_file($attachment_id));
                $clean_name = pathinfo($file_name, PATHINFO_FILENAME); // 移除扩展名
                $clean_name = str_replace(['-', '_', '%20'], ' ', $clean_name); // 支持多种分隔符
                
                // 语义有效性检测（排除纯数字或哈希值）
                if (!preg_match('/^[\d\W_]+$/', $clean_name)) { // 包含字母或汉字
                    $alt_text = ucwords(mb_strtolower($clean_name));
                }
            }

            // 3. 附件标题过滤（排除与文章标题相同的情况）
            if (empty($alt_text)) {
                $attachment = get_post($attachment_id);
                $attachment_title = sanitize_text_field($attachment->post_title);
                if (!empty($attachment_title) && $attachment_title !== $post_title) {
                    $alt_text = $attachment_title;
                }
            }
        }

        // 最终处理：文章标题 + 唯一序号
        if (empty($alt_text)) {
            $alt_text = sprintf('%s - 图示%s', $post_title, smart_counter($counter));
            $counter++;
        }

        // 智能属性注入
        if (preg_match('/\salt=(["\'])/i', $img_tag)) {
            return preg_replace('/(\salt=(["\'])).*?(\2)/i', '$1'.esc_attr($alt_text).'$3', $img_tag);
        } else {
            return preg_replace('/<img\s+/i', '<img alt="'.esc_attr($alt_text).'" ', $img_tag, 1);
        }
    }, $content);

    return $content;
}

// 生成智能序号（示例：1→A, 2→B...）
function smart_counter(&$num) {
    if ($num <= 26) {
        return chr(64 + $num); // 生成A-Z
    }
    return $num; // 超过26使用数字
}